==> DIRAC-8.0.0a17-py3-none-any.whl: DIRAC/DataManagementSystem/Service/TornadoFileCatalogHandler.py <==
########################################################################
# File: FileCatalogHandler.py
########################################################################
"""
:mod: FileCatalogHandler

.. module: FileCatalogHandler

:synopsis: FileCatalogHandler is a simple Replica and Metadata Catalog service

"""
# imports
import csv

from io import StringIO

# from DIRAC

from DIRAC import gLogger, S_ERROR
from DIRAC.DataManagementSystem.Service.FileCatalogHandler import FileCatalogHandlerMixin

from DIRAC.Core.Tornado.Server.TornadoService import TornadoService


sLog = gLogger.getSubLogger(__name__)


class TornadoFileCatalogHandler(FileCatalogHandlerMixin, TornadoService):
    """
    ..class:: FileCatalogHandler

    A simple Replica and Metadata Catalog service.
    """

    # This is needed because the mixin class uses `cls.log`
    log = sLog

    def export_streamToClient(self, seName):
        """This method used to transfer the SEDump to the client,
        formated as CSV with '|' separation

        :param seName: name of the se to dump

        :returns: the result of the FileHelper


        """

        retVal = self.getSEDump(seName)

        try:
            csvOutput = StringIO()
            writer = csv.writer(csvOutput, delimiter="|")
            writer.writerows(retVal)

            ret = csvOutput.getvalue()
            return ret

        except Exception as e:
            sLog.exception("Exception while sending seDump", repr(e))
            return S_ERROR("Exception while sendind seDump: %s" % repr(e))
        finally:
            csvOutput.close()

==> DIRAC-8.1.0a1-py3-none-any.whl: DIRAC/DataManagementSystem/Service/TornadoFileCatalogHandler.py <==
########################################################################
# File: FileCatalogHandler.py
########################################################################
"""
:mod: FileCatalogHandler

.. module: FileCatalogHandler

:synopsis: FileCatalogHandler is a simple Replica and Metadata Catalog service

"""
# imports
import json
import csv

from io import StringIO

# from DIRAC

from DIRAC import S_ERROR
from DIRAC.Core.Utilities.ReturnValues import returnValueOrRaise
from DIRAC.DataManagementSystem.Service.FileCatalogHandler import FileCatalogHandlerMixin

from DIRAC.Core.Tornado.Server.TornadoService import TornadoService


class TornadoFileCatalogHandler(FileCatalogHandlerMixin, TornadoService):
    """
    ..class:: FileCatalogHandler

    A simple Replica and Metadata Catalog service.
    """

    def export_streamToClient(self, jsonSENames):
        """This method is used to transfer the SEDump to the client,
        formated as CSV with '|' separation

        :param jsonSENames: json formated names of the SEs to dump

        :returns: the result of the FileHelper


        """
        seNames = json.loads(jsonSENames)
        csvOutput = None

        try:
            retVal = returnValueOrRaise(self.getSEDump(seNames))

            csvOutput = StringIO()
            writer = csv.writer(csvOutput, delimiter="|")
            writer.writerows(retVal)

            ret = csvOutput.getvalue()
            return ret

        except Exception as e:
            self.log.exception("Exception while sending seDump", repr(e))
            return S_ERROR("Exception while sendind seDump: %s" % repr(e))
        finally:
            if csvOutput is not None:
                csvOutput.close()
